@@ -18,10 +18,11 @@ from __future__ import annotations
 
 import asyncio
 import typing
+from collections.abc import Collection
 from typing import Any
 
 from asgiref.sync import sync_to_async
-from sqlalchemy import func
+from sqlalchemy import func, select
 
 from airflow.models import DagRun
 from airflow.providers.standard.utils.sensor_helper import _get_count
@@ -60,9 +61,9 @@ class WorkflowTrigger(BaseTrigger):
         logical_dates: list[datetime] | None = None,
         external_task_ids: typing.Collection[str] | None = None,
         external_task_group_id: str | None = None,
-        failed_states: typing.Iterable[str] | None = None,
-        skipped_states: typing.Iterable[str] | None = None,
-        allowed_states: typing.Iterable[str] | None = None,
+        failed_states: Collection[str] | None = None,
+        skipped_states: Collection[str] | None = None,
+        allowed_states: Collection[str] | None = None,
         poke_interval: float = 2.0,
         soft_fail: bool = False,
         **kwargs,
@@ -123,49 +124,47 @@ class WorkflowTrigger(BaseTrigger):
                     return
             allowed_count = await get_count_func(self.allowed_states)
 
-            if allowed_count == len(run_id_or_dates):  # type: ignore[arg-type]
+            if allowed_count == len(run_id_or_dates):
                 yield TriggerEvent({"status": "success"})
                 return
             self.log.info("Sleeping for %s seconds", self.poke_interval)
             await asyncio.sleep(self.poke_interval)
 
-    async def _get_count_af_3(self, states):
+    async def _get_count_af_3(self, states: Collection[str] | None) -> int:
         from airflow.providers.standard.utils.sensor_helper import _get_count_by_matched_states
         from airflow.sdk.execution_time.task_runner import RuntimeTaskInstance
 
-        params = {
-            "dag_id": self.external_dag_id,
-            "logical_dates": self.logical_dates,
-            "run_ids": self.run_ids,
-        }
         if self.external_task_ids:
             count = await sync_to_async(RuntimeTaskInstance.get_ti_count)(
-                task_ids=self.external_task_ids,  # type: ignore[arg-type]
-                states=states,
-                **params,
+                dag_id=self.external_dag_id,
+                task_ids=list(self.external_task_ids),
+                logical_dates=self.logical_dates,
+                run_ids=self.run_ids,
+                states=list(states) if states else None,
             )
-        elif self.external_task_group_id:
+            return int(count / len(self.external_task_ids))
+        if self.external_task_group_id:
             run_id_task_state_map = await sync_to_async(RuntimeTaskInstance.get_task_states)(
+                dag_id=self.external_dag_id,
                 task_group_id=self.external_task_group_id,
-                **params,
+                logical_dates=self.logical_dates,
+                run_ids=self.run_ids,
             )
             count = await sync_to_async(_get_count_by_matched_states)(
                 run_id_task_state_map=run_id_task_state_map,
-                states=states,
+                states=states or [],
             )
-        else:
-            count = await sync_to_async(RuntimeTaskInstance.get_dr_count)(
-                dag_id=self.external_dag_id,
-                logical_dates=self.logical_dates,
-                run_ids=self.run_ids,
-                states=states,
-            )
-        if self.external_task_ids:
-            return count / len(self.external_task_ids)
+            return count
+        count = await sync_to_async(RuntimeTaskInstance.get_dr_count)(
+            dag_id=self.external_dag_id,
+            logical_dates=self.logical_dates,
+            run_ids=self.run_ids,
+            states=list(states) if states else None,
+        )
         return count
 
     @sync_to_async
-    def _get_count(self, states: typing.Iterable[str] | None) -> int:
+    def _get_count(self, states: Collection[str] | None) -> int:
         """
         Get the count of records against dttm filter and states. Async wrapper for _get_count.
 
@@ -228,18 +227,18 @@ class DagStateTrigger(BaseTrigger):
             runs_ids_or_dates = len(self.execution_dates)
 
         if AIRFLOW_V_3_0_PLUS:
-            event = await self.validate_count_dags_af_3(runs_ids_or_dates_len=runs_ids_or_dates)
-            yield TriggerEvent(event)
+            data = await self.validate_count_dags_af_3(runs_ids_or_dates_len=runs_ids_or_dates)
+            yield TriggerEvent(data)
             return
         else:
             while True:
-                num_dags = await self.count_dags()  # type: ignore[call-arg]
+                num_dags = await self.count_dags()
                 if num_dags == runs_ids_or_dates:
                     yield TriggerEvent(self.serialize())
                     return
                 await asyncio.sleep(self.poll_interval)
 
-    async def validate_count_dags_af_3(self, runs_ids_or_dates_len: int = 0) -> tuple[str, dict[str, Any]]:
+    async def validate_count_dags_af_3(self, runs_ids_or_dates_len: int = 0) -> dict[str, typing.Any]:
         from airflow.sdk.execution_time.task_runner import RuntimeTaskInstance
 
         cls_path, data = self.serialize()
@@ -259,7 +258,7 @@ class DagStateTrigger(BaseTrigger):
                             run_id=run_id,
                         )
                         data[run_id] = state
-                        return cls_path, data
+                        return data
             await asyncio.sleep(self.poll_interval)
 
     if not AIRFLOW_V_3_0_PLUS:
@@ -270,17 +269,18 @@ class DagStateTrigger(BaseTrigger):
         def count_dags(self, *, session: Session = NEW_SESSION) -> int:
             """Count how many dag runs in the database match our criteria."""
             _dag_run_date_condition = (
-                DagRun.run_id.in_(self.run_ids)
+                DagRun.run_id.in_(self.run_ids or [])
                 if AIRFLOW_V_3_0_PLUS
                 else DagRun.execution_date.in_(self.execution_dates)
             )
-            count = (
-                session.query(func.count("*"))  # .count() is inefficient
-                .filter(
+            stmt = (
+                select(func.count())
+                .select_from(DagRun)
+                .where(
                     DagRun.dag_id == self.dag_id,
                     DagRun.state.in_(self.states),
                     _dag_run_date_condition,
                 )
-                .scalar()
             )
-            return typing.cast("int", count)
+            result = session.execute(stmt).scalar()
+            return result or 0
