@@ -104,7 +104,7 @@ class TestBashDecorator:
             assert bash_task.operator._init_bash_command_not_set is True
 
     @pytest.mark.parametrize(
-        argnames=["command", "expected_command", "expected_return_val"],
+        argnames=("command", "expected_command", "expected_return_val"),
         argvalues=[
             pytest.param("echo hello world", "echo hello world", "hello world", id="not_templated"),
             pytest.param(
@@ -175,7 +175,7 @@ class TestBashDecorator:
         self.validate_bash_command_rtif(ti, excepted_command)
 
     @pytest.mark.parametrize(
-        argnames=["append_env", "user_defined_env", "expected_airflow_home"],
+        argnames=("append_env", "user_defined_env", "expected_airflow_home"),
         argvalues=[
             pytest.param(False, {"var": "value"}, "", id="no_append_env"),
             pytest.param(True, {"var": "value"}, "path/to/airflow/home", id="append_env"),
@@ -203,7 +203,7 @@ class TestBashDecorator:
         self.validate_bash_command_rtif(ti, "echo var=$var; echo AIRFLOW_HOME=$AIRFLOW_HOME;")
 
     @pytest.mark.parametrize(
-        argnames=["exit_code", "expected"],
+        argnames=("exit_code", "expected"),
         argvalues=[
             pytest.param(99, pytest.raises(AirflowSkipException), id="skip"),
             pytest.param(1, pytest.raises(AirflowException), id="non-zero"),
@@ -228,7 +228,7 @@ class TestBashDecorator:
             self.validate_bash_command_rtif(ti, f"exit {exit_code}")
 
     @pytest.mark.parametrize(
-        argnames=["skip_on_exit_code", "exit_code", "expected"],
+        argnames=("skip_on_exit_code", "exit_code", "expected"),
         argvalues=[
             pytest.param(None, 99, pytest.raises(AirflowSkipException), id="default_skip_exit_99"),
             pytest.param(None, 1, pytest.raises(AirflowException), id="default_skip_exit_1"),
@@ -272,12 +272,12 @@ class TestBashDecorator:
             self.validate_bash_command_rtif(ti, f"exit {exit_code}")
 
     @pytest.mark.parametrize(
-        argnames=[
+        argnames=(
             "user_defined_env",
             "append_env",
             "expected_razz",
             "expected_airflow_home",
-        ],
+        ),
         argvalues=[
             pytest.param(
                 {"razz": "matazz"}, True, "matazz", "path/to/airflow/home", id="user_defined_env_and_append"
@@ -448,7 +448,7 @@ class TestBashDecorator:
         self.validate_bash_command_rtif(ti, "echo")
 
     @pytest.mark.parametrize(
-        argnames=["return_val", "expected"],
+        argnames=("return_val", "expected"),
         argvalues=[
             pytest.param(None, pytest.raises(TypeError), id="return_none_typeerror"),
             pytest.param(1, pytest.raises(TypeError), id="return_int_typeerror"),
