@@ -18,8 +18,6 @@ from __future__ import annotations
 
 import pytest
 
-from airflow.providers.standard.exceptions import HITLRejectException, HITLTimeoutError, HITLTriggerEventError
-
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_1_PLUS
 
 if not AIRFLOW_V_3_1_PLUS:
@@ -33,9 +31,10 @@ from urllib.parse import parse_qs, urlparse
 import pytest
 from sqlalchemy import select
 
-from airflow.exceptions import AirflowException, DownstreamTasksSkipped
+from airflow.exceptions import AirflowException, DownstreamTasksSkipped, ParamValidationError
 from airflow.models import TaskInstance, Trigger
 from airflow.models.hitl import HITLDetail
+from airflow.providers.standard.exceptions import HITLRejectException, HITLTimeoutError, HITLTriggerEventError
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.providers.standard.operators.hitl import (
     ApprovalOperator,
@@ -46,9 +45,9 @@ from airflow.providers.standard.operators.hitl import (
 from airflow.sdk import Param, timezone
 from airflow.sdk.definitions.param import ParamsDict
 from airflow.sdk.execution_time.hitl import HITLUser
-from airflow.utils.context import Context
 
 from tests_common.test_utils.config import conf_vars
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_1_3_PLUS
 
 if TYPE_CHECKING:
     from sqlalchemy.orm import Session
@@ -81,7 +80,7 @@ def hitl_task_and_ti_for_generating_link(dag_maker: DagMaker) -> tuple[HITLOpera
 
 
 @pytest.fixture
-def get_context_from_model_ti(mock_supervisor_comms):
+def get_context_from_model_ti(mock_supervisor_comms: Any) -> Any:
     def _get_context(ti: TaskInstance) -> Context:
         from airflow.api_fastapi.execution_api.datamodels.taskinstance import (
             DagRun as DRDataModel,
@@ -137,9 +136,27 @@ class TestHITLOperator:
                 params=ParamsDict({"input_1": 1}),
             )
 
-    def test_validate_params_with__options(self) -> None:
+    @pytest.mark.parametrize(
+        ("params", "exc", "error_msg"),
+        (
+            (ParamsDict({"_options": 1}), ValueError, '"_options" is not allowed in params'),
+            (
+                ParamsDict({"param": Param("", type="integer")}),
+                ParamValidationError,
+                (
+                    "Invalid input for param param: '' is not of type 'integer'\n\n"
+                    "Failed validating 'type' in schema:\n"
+                    "    {'type': 'integer'}\n\n"
+                    "On instance:\n    ''"
+                ),
+            ),
+        ),
+    )
+    def test_validate_params(
+        self, params: ParamsDict, exc: type[ValueError | ParamValidationError], error_msg: str
+    ) -> None:
         # validate_params is called during initialization
-        with pytest.raises(ValueError, match='"_options" is not allowed in params'):
+        with pytest.raises(exc, match=error_msg):
             HITLOperator(
                 task_id="hitl_test",
                 subject="This is subject",
@@ -147,7 +164,7 @@ class TestHITLOperator:
                 body="This is body",
                 defaults=["1"],
                 multiple=False,
-                params=ParamsDict({"_options": 1}),
+                params=params,
             )
 
     def test_validate_defaults(self) -> None:
@@ -163,7 +180,7 @@ class TestHITLOperator:
         hitl_op.validate_defaults()
 
     @pytest.mark.parametrize(
-        "extra_kwargs, expected_error_msg",
+        ("extra_kwargs", "expected_error_msg"),
         [
             ({"defaults": ["0"]}, r'defaults ".*" should be a subset of options ".*"'),
             (
@@ -211,43 +228,94 @@ class TestHITLOperator:
         ti = dag_maker.run_ti(task.task_id, dr)
 
         hitl_detail_model = session.scalar(select(HITLDetail).where(HITLDetail.ti_id == ti.id))
+        assert hitl_detail_model is not None
         assert hitl_detail_model.ti_id == ti.id
         assert hitl_detail_model.subject == "This is subject"
         assert hitl_detail_model.options == ["1", "2", "3", "4", "5"]
         assert hitl_detail_model.body == "This is body"
         assert hitl_detail_model.defaults == ["1"]
         assert hitl_detail_model.multiple is False
-        assert hitl_detail_model.params == {"input_1": 1}
         assert hitl_detail_model.assignees == [{"id": "test", "name": "test"}]
         assert hitl_detail_model.responded_at is None
         assert hitl_detail_model.responded_by is None
         assert hitl_detail_model.chosen_options is None
         assert hitl_detail_model.params_input == {}
+        if AIRFLOW_V_3_1_3_PLUS:
+            assert hitl_detail_model.params == {
+                "input_1": {
+                    "value": 1,
+                    "description": None,
+                    "schema": {},
+                }
+            }
+        else:
+            assert hitl_detail_model.params == {"input_1": 1}
 
         assert notifier.called is True
 
         registered_trigger = session.scalar(
             select(Trigger).where(Trigger.classpath == "airflow.providers.standard.triggers.hitl.HITLTrigger")
         )
+        assert registered_trigger is not None
         assert registered_trigger.kwargs == {
             "ti_id": ti.id,
             "options": ["1", "2", "3", "4", "5"],
             "defaults": ["1"],
-            "params": {"input_1": 1},
+            "params": {
+                "input_1": {
+                    "value": 1,
+                    "description": None,
+                    "schema": {},
+                }
+            },
             "multiple": False,
             "timeout_datetime": None,
             "poke_interval": 5.0,
         }
 
+    @pytest.mark.skipif(not AIRFLOW_V_3_1_3_PLUS, reason="This only works in airflow-core >= 3.1.3")
     @pytest.mark.parametrize(
-        "input_params, expected_params",
+        ("input_params", "expected_params"),
         [
-            (ParamsDict({"input": 1}), {"input": 1}),
-            ({"input": Param(5, type="integer", minimum=3)}, {"input": 5}),
+            (
+                ParamsDict({"input": 1}),
+                {
+                    "input": {
+                        "description": None,
+                        "schema": {},
+                        "value": 1,
+                    },
+                },
+            ),
+            (
+                {"input": Param(5, type="integer", minimum=3, description="test")},
+                {
+                    "input": {
+                        "value": 5,
+                        "schema": {
+                            "minimum": 3,
+                            "type": "integer",
+                        },
+                        "description": "test",
+                    }
+                },
+            ),
+            (
+                {"input": 1},
+                {
+                    "input": {
+                        "value": 1,
+                        "schema": {},
+                        "description": None,
+                    }
+                },
+            ),
             (None, {}),
         ],
     )
-    def test_serialzed_params(self, input_params, expected_params: dict[str, Any]) -> None:
+    def test_serialzed_params(
+        self, input_params: ParamsDict | dict[str, Any] | None, expected_params: dict[str, Any]
+    ) -> None:
         hitl_op = HITLOperator(
             task_id="hitl_test",
             subject="This is subject",
@@ -257,6 +325,20 @@ class TestHITLOperator:
         )
         assert hitl_op.serialized_params == expected_params
 
+    @pytest.mark.skipif(
+        AIRFLOW_V_3_1_3_PLUS,
+        reason="Preserve the old behavior if airflow-core < 3.1.3. Otherwise the UI will break.",
+    )
+    def test_serialzed_params_legacy(self) -> None:
+        hitl_op = HITLOperator(
+            task_id="hitl_test",
+            subject="This is subject",
+            body="This is body",
+            options=["1", "2", "3", "4", "5"],
+            params={"input": Param(1)},
+        )
+        assert hitl_op.serialized_params == {"input": 1}
+
     def test_execute_complete(self) -> None:
         hitl_op = HITLOperator(
             task_id="hitl_test",
@@ -286,7 +368,7 @@ class TestHITLOperator:
         }
 
     @pytest.mark.parametrize(
-        "event, expected_exception",
+        ("event", "expected_exception"),
         [
             ({"error": "unknown", "error_type": "unknown"}, HITLTriggerEventError),
             ({"error": "this is timeotu", "error_type": "timeout"}, HITLTimeoutError),
@@ -295,7 +377,7 @@ class TestHITLOperator:
     def test_process_trigger_event_error(
         self,
         event: dict[str, Any],
-        expected_exception,
+        expected_exception: type[Exception],
     ) -> None:
         hitl_op = HITLOperator(
             task_id="hitl_test",
@@ -326,27 +408,53 @@ class TestHITLOperator:
                 },
             )
 
-    def test_validate_params_input_with_invalid_input(self) -> None:
+    @pytest.mark.parametrize(
+        ("params", "params_input", "exc", "error_msg"),
+        (
+            (
+                ParamsDict({"input": 1}),
+                {"no such key": 2, "input": 333},
+                ValueError,
+                "params_input {'no such key': 2, 'input': 333} does not match params {'input': 1}",
+            ),
+            (
+                ParamsDict({"input": Param(3, type="number", minimum=3)}),
+                {"input": 0},
+                ParamValidationError,
+                (
+                    "Invalid input for param input: 0 is less than the minimum of 3\n\n"
+                    "Failed validating 'minimum' in schema:\n.*"
+                ),
+            ),
+        ),
+    )
+    def test_validate_params_input_with_invalid_input(
+        self,
+        params: ParamsDict,
+        params_input: dict[str, Any],
+        exc: type[ValueError | ParamValidationError],
+        error_msg: str,
+    ) -> None:
         hitl_op = HITLOperator(
             task_id="hitl_test",
             subject="This is subject",
             body="This is body",
             options=["1", "2", "3", "4", "5"],
-            params={"input": 1},
+            params=params,
         )
 
-        with pytest.raises(ValueError, match="no such key"):
+        with pytest.raises(exc, match=error_msg):
             hitl_op.execute_complete(
                 context={},
                 event={
                     "chosen_options": ["1"],
-                    "params_input": {"no such key": 2, "input": 333},
+                    "params_input": params_input,
                     "responded_by_user": {"id": "test", "name": "test"},
                 },
             )
 
     @pytest.mark.parametrize(
-        "options, params_input, expected_parsed_query",
+        ("options", "params_input", "expected_parsed_query"),
         [
             (None, None, {"map_index": ["-1"]}),
             ("1", None, {"_options": ["['1']"], "map_index": ["-1"]}),
@@ -410,7 +518,7 @@ class TestHITLOperator:
             assert parse_qs(parse_result.query) == expected_parsed_query
 
     @pytest.mark.parametrize(
-        "options, params_input, expected_err_msg",
+        ("options", "params_input", "expected_err_msg"),
         [
             ([100, "2", 30000], None, "options {.*} are not valid options"),
             (
@@ -422,7 +530,7 @@ class TestHITLOperator:
     )
     def test_generate_link_to_ui_with_invalid_input(
         self,
-        options: list[str] | None,
+        options: list[Any] | None,
         params_input: dict[str, Any] | None,
         expected_err_msg: str,
         hitl_task_and_ti_for_generating_link: tuple[HITLOperator, TaskInstance],
@@ -452,7 +560,7 @@ class TestApprovalOperator:
             )
 
     def test_init_with_multiple_set_to_true(self) -> None:
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Passing multiple to ApprovalOperator is not allowed."):
             ApprovalOperator(
                 task_id="hitl_test",
                 subject="This is subject",
@@ -486,7 +594,7 @@ class TestApprovalOperator:
         }
 
     def test_execute_complete_with_downstream_tasks(
-        self, dag_maker: DagMaker, get_context_from_model_ti
+        self, dag_maker: DagMaker, get_context_from_model_ti: Any
     ) -> None:
         with dag_maker("hitl_test_dag", serialized=True):
             hitl_op = ApprovalOperator(
@@ -510,7 +618,7 @@ class TestApprovalOperator:
         assert set(exc_info.value.tasks) == {"op1"}
 
     def test_execute_complete_with_fail_on_reject_set_to_true(
-        self, dag_maker: DagMaker, get_context_from_model_ti
+        self, dag_maker: DagMaker, get_context_from_model_ti: Any
     ) -> None:
         with dag_maker("hitl_test_dag", serialized=True):
             hitl_op = ApprovalOperator(task_id="hitl_test", subject="This is subject", fail_on_reject=True)
@@ -568,7 +676,7 @@ class TestHITLEntryOperator:
 
 
 class TestHITLBranchOperator:
-    def test_execute_complete(self, dag_maker: DagMaker, get_context_from_model_ti) -> None:
+    def test_execute_complete(self, dag_maker: DagMaker, get_context_from_model_ti: Any) -> None:
         with dag_maker("hitl_test_dag", serialized=True):
             branch_op = HITLBranchOperator(
                 task_id="make_choice",
@@ -593,7 +701,7 @@ class TestHITLBranchOperator:
         assert set(exc_info.value.tasks) == set((f"branch_{i}", -1) for i in range(2, 6))
 
     def test_execute_complete_with_multiple_branches(
-        self, dag_maker: DagMaker, get_context_from_model_ti
+        self, dag_maker: DagMaker, get_context_from_model_ti: Any
     ) -> None:
         with dag_maker("hitl_test_dag", serialized=True):
             branch_op = HITLBranchOperator(
@@ -621,7 +729,9 @@ class TestHITLBranchOperator:
             )
         assert set(exc_info.value.tasks) == set((f"branch_{i}", -1) for i in range(4, 6))
 
-    def test_mapping_applies_for_single_choice(self, dag_maker: DagMaker, get_context_from_model_ti) -> None:
+    def test_mapping_applies_for_single_choice(
+        self, dag_maker: DagMaker, get_context_from_model_ti: Any
+    ) -> None:
         # ["Approve"]; map -> "publish"
         with dag_maker("hitl_map_dag", serialized=True):
             op = HITLBranchOperator(
@@ -648,7 +758,7 @@ class TestHITLBranchOperator:
         # checks to see that the "archive" task was skipped
         assert set(exc.value.tasks) == {("archive", -1)}
 
-    def test_mapping_with_multiple_choices(self, dag_maker: DagMaker, get_context_from_model_ti) -> None:
+    def test_mapping_with_multiple_choices(self, dag_maker: DagMaker, get_context_from_model_ti: Any) -> None:
         # multiple=True; mapping applied per option; no dedup implied
         with dag_maker("hitl_map_dag", serialized=True):
             op = HITLBranchOperator(
@@ -680,7 +790,9 @@ class TestHITLBranchOperator:
         # publish + keep chosen → only "other" skipped
         assert set(exc.value.tasks) == {("other", -1)}
 
-    def test_fallback_to_option_when_not_mapped(self, dag_maker: DagMaker, get_context_from_model_ti) -> None:
+    def test_fallback_to_option_when_not_mapped(
+        self, dag_maker: DagMaker, get_context_from_model_ti: Any
+    ) -> None:
         # No mapping: option must match downstream task_id
         with dag_maker("hitl_map_dag", serialized=True):
             op = HITLBranchOperator(
@@ -706,8 +818,8 @@ class TestHITLBranchOperator:
         assert set(exc.value.tasks) == {("branch_1", -1)}
 
     def test_error_if_mapped_branch_not_direct_downstream(
-        self, dag_maker: DagMaker, get_context_from_model_ti
-    ):
+        self, dag_maker: DagMaker, get_context_from_model_ti: Any
+    ) -> None:
         # Don't add the mapped task downstream → expect a clean error
         with dag_maker("hitl_map_dag", serialized=True):
             op = HITLBranchOperator(
@@ -733,7 +845,7 @@ class TestHITLBranchOperator:
             )
 
     @pytest.mark.parametrize("bad", [123, ["publish"], {"x": "y"}, b"publish"])
-    def test_options_mapping_non_string_value_raises(self, bad):
+    def test_options_mapping_non_string_value_raises(self, bad: Any) -> None:
         with pytest.raises(ValueError, match=r"values must be strings \(task_ids\)"):
             HITLBranchOperator(
                 task_id="choose",
@@ -742,7 +854,7 @@ class TestHITLBranchOperator:
                 options_mapping={"Approve": bad},
             )
 
-    def test_options_mapping_key_not_in_options_raises(self):
+    def test_options_mapping_key_not_in_options_raises(self) -> None:
         with pytest.raises(ValueError, match="contains keys that are not in `options`"):
             HITLBranchOperator(
                 task_id="choose",
