@@ -19,7 +19,6 @@ from __future__ import annotations
 
 import copy
 import logging
-import logging.config
 import os
 import pickle
 import re
@@ -61,7 +60,7 @@ from airflow.providers.standard.operators.python import (
     _PythonVersionInfo,
     get_current_context,
 )
-from airflow.providers.standard.utils.python_virtualenv import execute_in_subprocess, prepare_virtualenv
+from airflow.providers.standard.utils.python_virtualenv import _execute_in_subprocess, prepare_virtualenv
 from airflow.utils.session import create_session
 from airflow.utils.state import DagRunState, State, TaskInstanceState
 from airflow.utils.types import NOTSET, DagRunType
@@ -339,7 +338,7 @@ class TestPythonOperator(BasePythonTest):
         self.run_as_task(func, op_kwargs={"custom": 1})
 
     @pytest.mark.parametrize(
-        "show_return_value_in_logs, should_shown",
+        ("show_return_value_in_logs", "should_shown"),
         [
             pytest.param(NOTSET, True, id="default"),
             pytest.param(True, True, id="show"),
@@ -581,7 +580,7 @@ class TestBranchOperator(BasePythonTest):
             )
 
     @pytest.mark.parametrize(
-        "choice,expected_states",
+        ("choice", "expected_states"),
         [
             ("task1", [State.SUCCESS, State.SUCCESS, State.SUCCESS]),
             ("join", [State.SUCCESS, State.SKIPPED, State.SUCCESS]),
@@ -646,10 +645,14 @@ class TestShortCircuitOperator(BasePythonTest):
     all_success_skipped_tasks: set[str] = set()
 
     @pytest.mark.parametrize(
-        argnames=(
-            "callable_return, test_ignore_downstream_trigger_rules, test_trigger_rule, expected_skipped_tasks, expected_task_states"
+        (
+            "callable_return",
+            "test_ignore_downstream_trigger_rules",
+            "test_trigger_rule",
+            "expected_skipped_tasks",
+            "expected_task_states",
         ),
-        argvalues=[
+        [
             # Skip downstream tasks, do not respect trigger rules, default trigger rule on all downstream
             # tasks
             (
@@ -955,7 +958,6 @@ class BaseTestPythonVirtualenvOperator(BasePythonTest):
 
     def test_string_args(self):
         def f():
-            global virtualenv_string_args
             print(virtualenv_string_args)
             if virtualenv_string_args[0] != virtualenv_string_args[2]:
                 raise RuntimeError
@@ -1075,7 +1077,7 @@ class BaseTestPythonVirtualenvOperator(BasePythonTest):
         assert set(context) == declared_keys
 
     @pytest.mark.parametrize(
-        "kwargs, actual_exit_code, expected_state",
+        ("kwargs", "actual_exit_code", "expected_state"),
         [
             ({}, 0, TaskInstanceState.SUCCESS),
             ({}, 100, TaskInstanceState.FAILED),
@@ -1239,7 +1241,7 @@ class TestPythonVirtualenvOperator(BaseTestPythonVirtualenvOperator):
         self.run_as_task(f)
 
     @pytest.mark.parametrize(
-        "serializer, extra_requirements",
+        ("serializer", "extra_requirements"),
         [
             pytest.param("pickle", [], id="pickle"),
             pytest.param("dill", ["dill"], marks=DILL_MARKER, id="dill"),
@@ -1291,7 +1293,7 @@ class TestPythonVirtualenvOperator(BaseTestPythonVirtualenvOperator):
         self.run_as_task(f, requirements=["funcsigs==0.4"], do_not_use_caching=True)
 
     @pytest.mark.parametrize(
-        "serializer, extra_requirements",
+        ("serializer", "extra_requirements"),
         [
             pytest.param("pickle", [], id="pickle"),
             pytest.param("dill", ["dill"], marks=DILL_MARKER, id="dill"),
@@ -1311,7 +1313,7 @@ class TestPythonVirtualenvOperator(BaseTestPythonVirtualenvOperator):
         )
 
     @pytest.mark.parametrize(
-        "serializer, extra_requirements",
+        ("serializer", "extra_requirements"),
         [
             pytest.param("pickle", [], id="pickle"),
             pytest.param("dill", ["dill"], marks=DILL_MARKER, id="dill"),
@@ -1382,7 +1384,7 @@ class TestPythonVirtualenvOperator(BaseTestPythonVirtualenvOperator):
         )
 
     @pytest.mark.parametrize(
-        "serializer, extra_requirements",
+        ("serializer", "extra_requirements"),
         [
             pytest.param("pickle", [], id="pickle"),
             pytest.param("dill", ["dill"], marks=DILL_MARKER, id="dill"),
@@ -1410,8 +1412,8 @@ class TestPythonVirtualenvOperator(BaseTestPythonVirtualenvOperator):
         self.run_as_task(f, system_site_packages=False, op_args=[4])
 
     @mock.patch(
-        "airflow.providers.standard.utils.python_virtualenv.execute_in_subprocess",
-        wraps=execute_in_subprocess,
+        "airflow.providers.standard.utils.python_virtualenv._execute_in_subprocess",
+        wraps=_execute_in_subprocess,
     )
     def test_with_index_urls(self, wrapped_execute_in_subprocess):
         def f(a):
@@ -1601,7 +1603,7 @@ class TestPythonVirtualenvOperator(BaseTestPythonVirtualenvOperator):
         self.run_as_task(f, serializer=serializer, system_site_packages=False, requirements=None)
 
     @pytest.mark.parametrize(
-        "requirements, system_site, want_airflow, want_pendulum",
+        ("requirements", "system_site", "want_airflow", "want_pendulum"),
         [
             # nothing → just base keys
             ([], False, False, False),
@@ -2241,7 +2243,7 @@ class TestCurrentContextRuntime:
 @pytest.mark.need_serialized_dag(False)
 class TestShortCircuitWithTeardown:
     @pytest.mark.parametrize(
-        "ignore_downstream_trigger_rules, with_teardown, should_skip, expected",
+        ("ignore_downstream_trigger_rules", "with_teardown", "should_skip", "expected"),
         [
             (False, True, True, ["op2"]),
             (False, True, False, []),
@@ -2379,7 +2381,7 @@ class TestShortCircuitWithTeardown:
 
 
 @pytest.mark.parametrize(
-    "text_input, expected_tuple",
+    ("text_input", "expected_tuple"),
     [
         pytest.param("   2.7.18.final.0  ", (2, 7, 18, "final", 0), id="py27"),
         pytest.param("3.10.13.final.0\n", (3, 10, 13, "final", 0), id="py310"),
