@@ -75,7 +75,6 @@ class TestWorkflowTrigger:
         mock_get_count.assert_called_once_with(
             dag_id="external_task",
             task_ids=["external_task_op"],
-            task_group_id=None,
             logical_dates=[self.LOGICAL_DATE],
             run_ids=None,
             states=["success", "fail"],
@@ -112,7 +111,6 @@ class TestWorkflowTrigger:
         mock_get_count.assert_called_once_with(
             dag_id="external_task",
             task_ids=["external_task_op"],
-            task_group_id=None,
             logical_dates=[self.LOGICAL_DATE],
             run_ids=[self.RUN_ID],
             states=["success", "fail"],
@@ -124,7 +122,7 @@ class TestWorkflowTrigger:
     @pytest.mark.asyncio
     @mock.patch("airflow.sdk.execution_time.task_runner.RuntimeTaskInstance.get_ti_count")
     async def test_task_workflow_trigger_fail_count_eq_0(self, mock_get_count):
-        mock_get_count.return_value = 0
+        mock_get_count.side_effect = [0, 1]  # First 0 for failed_states, then 1 for allowed_states
 
         trigger = WorkflowTrigger(
             external_dag_id=self.DAG_ID,
@@ -132,6 +130,7 @@ class TestWorkflowTrigger:
             run_ids=[self.RUN_ID],
             external_task_ids=[self.TASK_ID],
             failed_states=self.STATES,
+            allowed_states=self.STATES,
             poke_interval=0.2,
         )
 
@@ -142,14 +141,22 @@ class TestWorkflowTrigger:
         result = trigger_task.result()
         assert isinstance(result, TriggerEvent)
         assert result.payload == {"status": "success"}
-        mock_get_count.assert_called_once_with(
-            dag_id="external_task",
-            task_ids=["external_task_op"],
-            task_group_id=None,
-            logical_dates=[self.LOGICAL_DATE],
-            run_ids=[self.RUN_ID],
-            states=["success", "fail"],
+
+        # Verify both calls were made
+        assert mock_get_count.call_count == 2
+        mock_get_count.assert_has_calls(
+            [
+                mock.call(
+                    dag_id="external_task",
+                    task_ids=["external_task_op"],
+                    logical_dates=[self.LOGICAL_DATE],
+                    run_ids=[self.RUN_ID],
+                    states=["success", "fail"],
+                ),
+            ]
+            * 2
         )
+
         # test that it returns after yielding
         with pytest.raises(StopAsyncIteration):
             await gen.__anext__()
@@ -181,7 +188,6 @@ class TestWorkflowTrigger:
         mock_get_count.assert_called_once_with(
             dag_id="external_task",
             task_ids=["external_task_op"],
-            task_group_id=None,
             logical_dates=[self.LOGICAL_DATE],
             run_ids=None,
             states=["success", "fail"],
@@ -218,7 +224,16 @@ class TestWorkflowTrigger:
         assert mock_sleep.await_count == 1
 
     @pytest.mark.parametrize(
-        "task_ids, task_group_id, states, logical_dates, mock_ti_count, mock_dag_count, expected",
+        (
+            "task_ids",
+            "task_group_id",
+            "states",
+            "logical_dates",
+            "mock_ti_count",
+            "mock_task_states",
+            "mock_dag_count",
+            "expected",
+        ),
         [
             (
                 ["task_id_one", "task_id_two"],
@@ -229,7 +244,8 @@ class TestWorkflowTrigger:
                     timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
                 ],
                 4,
-                2,
+                None,
+                None,
                 2,
             ),
             (
@@ -240,9 +256,42 @@ class TestWorkflowTrigger:
                     timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
                     timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
                 ],
+                None,
+                {"run_id_one": {"group1.task_id": "success"}, "run_id_two": {"group1.task_id": "success"}},
+                None,
                 2,
-                2,
-                2,
+            ),
+            (
+                [],
+                "task_group_id",
+                ["success"],
+                [
+                    timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
+                    timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
+                ],
+                None,
+                {
+                    "run_id_one": {"task_group_id.task_id": "success"},
+                    "run_id_two": {"task_group_id.task_id": "failed"},
+                },
+                None,
+                1,
+            ),
+            (
+                [],
+                "task_group_id",
+                ["success"],
+                [
+                    timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
+                    timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
+                ],
+                None,
+                {
+                    "run_id_one": {"task_group_id.task_id": "success"},
+                    "run_id_two": {"task_group_id.task_id": "skipped"},
+                },
+                None,
+                1,
             ),
             (
                 [],
@@ -252,7 +301,8 @@ class TestWorkflowTrigger:
                     timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
                     timezone.datetime(2020, 7, 6, 13, tzinfo=timezone.utc),
                 ],
-                2,
+                None,
+                None,
                 2,
                 2,
             ),
@@ -260,21 +310,26 @@ class TestWorkflowTrigger:
         ids=[
             "with_task_ids",
             "with task_group_id only",
+            "with task_group_id and some task_ids failed",
+            "without task_group_id and some task_ids skipped",
             "no task_ids or task_group_id",
         ],
     )
     @mock.patch("airflow.sdk.execution_time.task_runner.RuntimeTaskInstance.get_ti_count")
+    @mock.patch("airflow.sdk.execution_time.task_runner.RuntimeTaskInstance.get_task_states")
     @mock.patch("airflow.sdk.execution_time.task_runner.RuntimeTaskInstance.get_dr_count")
     @pytest.mark.asyncio
     async def test_get_count_af_3(
         self,
         mock_get_dr_count,
+        mock_get_task_states,
         mock_get_ti_count,
         task_ids,
         task_group_id,
         states,
         logical_dates,
         mock_ti_count,
+        mock_task_states,
         mock_dag_count,
         expected,
     ):
@@ -287,6 +342,7 @@ class TestWorkflowTrigger:
 
         mock_get_ti_count.return_value = mock_ti_count
         mock_get_dr_count.return_value = mock_dag_count
+        mock_get_task_states.return_value = mock_task_states
 
         trigger = WorkflowTrigger(
             external_dag_id=self.DAG_ID,
@@ -300,9 +356,19 @@ class TestWorkflowTrigger:
         get_count_af_3 = await trigger._get_count_af_3(states)
         assert get_count_af_3 == expected
 
-        if task_ids or task_group_id:
+        if task_ids:
             mock_get_ti_count.assert_called_once()
             assert mock_get_ti_count.call_count == 1
+            mock_get_task_states.assert_not_called()
+            assert mock_get_task_states.call_count == 0
+            mock_get_dr_count.assert_not_called()
+            assert mock_get_dr_count.call_count == 0
+
+        elif task_group_id:
+            mock_get_task_states.assert_called_once()
+            assert mock_get_task_states.call_count == 1
+            mock_get_ti_count.assert_not_called()
+            assert mock_get_ti_count.call_count == 0
             mock_get_dr_count.assert_not_called()
             assert mock_get_dr_count.call_count == 0
 
@@ -311,6 +377,8 @@ class TestWorkflowTrigger:
             assert mock_get_dr_count.call_count == 1
             mock_get_ti_count.assert_not_called()
             assert mock_get_ti_count.call_count == 0
+            mock_get_task_states.assert_not_called()
+            assert mock_get_task_states.call_count == 0
 
     def test_serialization(self):
         """
@@ -419,15 +487,20 @@ class TestWorkflowTriggerAF2:
             await gen.__anext__()
 
     @mock.patch("airflow.providers.standard.triggers.external_task._get_count")
+    @mock.patch("asyncio.sleep")
     @pytest.mark.asyncio
-    async def test_task_workflow_trigger_fail_count_eq_0(self, mock_get_count):
-        mock_get_count.return_value = 0
+    async def test_task_workflow_trigger_fail_count_eq_0(self, mock_sleep, mock_get_count):
+        mock_get_count.side_effect = [
+            0,
+            1,
+        ]
 
         trigger = WorkflowTrigger(
             external_dag_id=self.DAG_ID,
             **_DATES,
             external_task_ids=[self.TASK_ID],
             failed_states=self.STATES,
+            allowed_states=self.STATES,
             poke_interval=0.2,
         )
 
@@ -438,14 +511,23 @@ class TestWorkflowTriggerAF2:
         result = trigger_task.result()
         assert isinstance(result, TriggerEvent)
         assert result.payload == {"status": "success"}
-        mock_get_count.assert_called_once_with(
-            dttm_filter=value,
-            external_task_ids=["external_task_op"],
-            external_task_group_id=None,
-            external_dag_id="external_task",
-            states=["success", "fail"],
+
+        assert mock_get_count.call_count == 2
+        mock_get_count.assert_has_calls(
+            [
+                mock.call(
+                    dttm_filter=value,
+                    external_task_ids=["external_task_op"],
+                    external_task_group_id=None,
+                    external_dag_id="external_task",
+                    states=["success", "fail"],
+                ),
+            ]
+            * 2
         )
-        # test that it returns after yielding
+
+        mock_sleep.assert_not_called()
+
         with pytest.raises(StopAsyncIteration):
             await gen.__anext__()
 
